Class: Api::V1::RoleTypesController
- Inherits:
-
BaseController
- Object
- ActionController::Base
- BaseController
- Api::V1::RoleTypesController
- Defined in:
- app/controllers/api/v1/role_types_controller.rb
Instance Method Summary collapse
Instance Method Details
#create ⇒ Object
120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 |
# File 'app/controllers/api/v1/role_types_controller.rb', line 120 def create description = params[:description].strip begin ActiveRecord::Base.transaction do role_type = RoleType.create!(description: description, internal_identifier: description.to_iid) if params[:parent] != 'No Parent' parent = RoleType.iid(params[:parent]) role_type.move_to_child_of(parent) elsif params[:default_parent] parent = RoleType.iid(params[:default_parent]) role_type.move_to_child_of(parent) end render :json => {success: true, role_type: role_type.to_hash(only: [:id, :description, :internal_identifier])} end rescue ActiveRecord::RecordInvalid => invalid Rails.logger.error invalid.record.errors. render :json => {:success => false, :message => invalid.record.errors..join('</br>')} end end |
#index ⇒ Object
5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 |
# File 'app/controllers/api/v1/role_types_controller.rb', line 5 def index if params[:party_id] party = Party.find(params[:party_id]) render :json => {success: true, role_types: party.role_types.collect{|role_type| role_type.to_data_hash}} elsif params[:parent] parent = nil # create parent if it doesn't exist # if the parent param is a comma seperated string then # the parent is nested from left to right params[:parent].split(',').each do |parent_iid| if parent parent = RoleType.find_or_create(parent_iid, parent_iid.humanize, parent) else parent = RoleType.find_or_create(parent_iid, parent_iid.humanize) end end respond_to do |format| format.tree do render :json => {success: true, role_types: parent.children_to_tree_hash} end format.json do render :json => {success: true, role_types: RoleType.to_all_representation(parent)} end end # if ids are passed look up on the Role Types with the ids passed elsif params[:ids] ids = params[:ids].split(',').compact role_types = [] ids.each do |id| # check if id is a integer if so fine by id if id.is_integer? role_type = RoleType.find(id) else role_type = RoleType.iid(id) end if role_type respond_to do |format| format.tree do data = role_type.to_hash({ only: [:id, :parent_id, :internal_identifier], leaf: role_type.leaf?, text: role_type.to_label, children: [] }) parent = nil role_types.each do |role_type_hash| if role_type_hash[:id] == data[:parent_id] parent = role_type_hash end end if parent parent[:children].push(data) else role_types.push(data) end end format.json do role_types.push(role_type.to_hash(only: [:id, :description, :internal_identifier])) end end end end render :json => {success: true, role_types: role_types} # get all role types else respond_to do |format| format.tree do nodes = [].tap do |nodes| RoleType.roots.each do |root| nodes.push(root.to_tree_hash) end end render :json => {success: true, role_types: nodes} end format.json do render :json => {success: true, role_types: RoleType.to_all_representation} end end end end |
#show ⇒ Object
100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 |
# File 'app/controllers/api/v1/role_types_controller.rb', line 100 def show id = params[:id] # check if id is a integer if so fine by id if id.is_integer? role_type = RoleType.find(id) else role_type = RoleType.iid(id) end respond_to do |format| format.tree do render :json => {success: true, role_type: role_type.to_tree_hash} end format.json do render :json => {success: true, role_type: role_type.to_hash(only: [:id, :description, :internal_identifier])} end end end |