Class: IsoCountryCode
- Inherits:
-
GeoCountry
- Object
- ActiveRecord::Base
- GeoCountry
- IsoCountryCode
- Defined in:
- app/models/iso_country_code.rb
Instance Method Summary collapse
-
#short_name ⇒ Object
TODO validate identifier is iso alphabetic two digit code.
Methods inherited from GeoCountry
Instance Method Details
#short_name ⇒ Object
TODO validate identifier is iso alphabetic two digit code
5 6 7 |
# File 'app/models/iso_country_code.rb', line 5 def short_name name end |